@@ -1,6 +1,3 @@
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import sys
 import os
 import configargparse
@@ -13,33 +10,28 @@ from ct.hunter import Hunter
 
 
 class FlatStyle(ct.git_utils.NameAdjuster):
-
     def __call__(self, sourcefiles):
         for source in sourcefiles:
             print(self.adjust(source))
 
 
 class IndentStyle(ct.git_utils.NameAdjuster):
-
     def __call__(self, sourcefiles):
         for source in sourcefiles:
-            print('\t', self.adjust(source))
+            print("\t", self.adjust(source))
 
 
 class HeaderPassFilter(object):
-
     def __call__(self, files):
         return {fn for fn in files if ct.utils.isheader(fn)}
 
 
 class SourcePassFilter(object):
-
     def __call__(self, files):
         return {fn for fn in files if ct.utils.issource(fn)}
 
 
 class AllPassFilter(object):
-
     def __call__(self, files):
         return files
 
@@ -51,66 +43,64 @@ def check_filename(filename):
             "Did you spell it correctly?"
             "Another possible reason is that you didn't supply a filename"
             " and that configargparse has picked an unused positional argument"
-            " from the config file.\n".format(filename))
+            " from the config file.\n".format(filename)
+        )
         exit(1)
 
 
 class Filelist(object):
-
     def __init__(self, args, hunter, style=None):
         self.args = args
         self._hunter = hunter
 
         if style is None:
             style = self.args.style
-        styleclass = globals()[style.title() + 'Style']
+        styleclass = globals()[style.title() + "Style"]
         self.styleobject = styleclass(args)
 
     @staticmethod
     def add_arguments(cap):
         ct.apptools.add_target_arguments(cap)
         cap.add(
-            '--extrafile',
-            help='Extra files to directly add to the filelist',
-            nargs='*')
+            "--extrafile", help="Extra files to directly add to the filelist", nargs="*"
+        )
         cap.add(
-            '--extradir',
-            help='Extra directories to add all files from to the filelist',
-            nargs='*')
+            "--extradir",
+            help="Extra directories to add all files from to the filelist",
+            nargs="*",
+        )
         cap.add(
-            '--extrafilelist',
-            help='Read the given files to find a list of extra files to add to the filelist',
-            nargs='*')
+            "--extrafilelist",
+            help="Read the given files to find a list of extra files to add to the filelist",
+            nargs="*",
+        )
 
         # Figure out what output style classes are available and add them to the
         # command line options
-        styles = [st[:-5].lower()
-                  for st in dict(globals()) if st.endswith('Style')]
+        styles = [st[:-5].lower() for st in dict(globals()) if st.endswith("Style")]
         cap.add(
-            '--style',
-            choices=styles,
-            default='flat',
-            help="Output formatting style")
+            "--style", choices=styles, default="flat", help="Output formatting style"
+        )
 
-        passfilters = [st[:-10].lower()
-                       for st in dict(globals()) if st.endswith('PassFilter')]
+        passfilters = [
+            st[:-10].lower() for st in dict(globals()) if st.endswith("PassFilter")
+        ]
         cap.add(
-            '--filter',
+            "--filter",
             choices=passfilters,
-            default='all',
-            help="What type of files are allowed in the output")
+            default="all",
+            help="What type of files are allowed in the output",
+        )
 
         ct.utils.add_flag_argument(
-            cap,
-            'merge',
-            default=True,
-            help='Merge all outputs into a single list')
+            cap, "merge", default=True, help="Merge all outputs into a single list"
+        )
         ct.hunter.add_arguments(cap)
 
     def process(self):
-        filterclass = globals()[self.args.filter.title() + 'PassFilter']
+        filterclass = globals()[self.args.filter.title() + "PassFilter"]
         filterobject = filterclass()
-        extras = set()
+        extras = ct.utils.OrderedSet()
 
         # Add all the command line specified extras
         if self.args.extrafile:
@@ -118,12 +108,10 @@ class Filelist(object):
         if self.args.extradir:
             for ed in self.args.extradir:
                 extras |= {
-                    os.path.join(
-                        ed,
-                        ff) for ff in os.listdir(ed) if ct.wrappedos.isfile(
-                        os.path.join(
-                            ed,
-                            ff))}
+                    os.path.join(ed, ff)
+                    for ff in os.listdir(ed)
+                    if ct.wrappedos.isfile(os.path.join(ed, ff))
+                }
         if self.args.extrafilelist:
             for fname in self.args.extrafilelist:
                 with open(fname) as ff:
@@ -133,25 +121,30 @@ class Filelist(object):
         if self.args.tests:
             for testfile in self.args.tests:
                 testdir = ct.wrappedos.dirname(ct.wrappedos.realpath(testfile))
-                extras |= {fileintestdir for fileintestdir in os.listdir(
-                    testdir) if ct.wrappedos.isfile(fileintestdir)}
+                extras |= {
+                    fileintestdir
+                    for fileintestdir in os.listdir(testdir)
+                    if ct.wrappedos.isfile(fileintestdir)
+                }
 
-        mergedfiles = set()
+        mergedfiles = ct.utils.OrderedSet()
         if self.args.merge:
             filteredfiles = filterobject(
-                {ct.wrappedos.realpath(fname) for fname in extras})
+                {ct.wrappedos.realpath(fname) for fname in extras}
+            )
             mergedfiles |= filteredfiles
         else:
             for fname in extras:
                 realpath = ct.wrappedos.realpath(fname)
                 print(self.styleobject.adjust(realpath))
 
-        followable = set()
+        followable = ct.utils.OrderedSet()
         lists = [
             self.args.filename,
             self.args.static,
             self.args.dynamic,
-            self.args.tests]
+            self.args.tests,
+        ]
         for ll in lists:
             if ll:
                 followable |= set(ll)
