@@ -3,8 +3,6 @@ import os
 import sys
 from io import open
 
-PY3 = sys.version_info[0] == 3
-
 import configargparse
 
 import ct.utils
@@ -268,12 +266,7 @@ class MakefileCreator:
             return False
 
         # See how the Makefile was previously generated
-        if PY3:
-            expected = "".join(["# Makefile generated by ", str(self.args)])
-        else:
-            expected = "".join(
-                ["# Makefile generated by ", str(self.args).decode("unicode_escape")]
-            )
+        expected = "".join(["# Makefile generated by ", str(self.args)])
 
         with open(self.args.makefilename, mode="r", encoding="utf-8") as mfile:
             previous = mfile.readline().strip()
@@ -686,10 +679,7 @@ class MakefileCreator:
         """ Take a list of rules and write the rules to a Makefile """
         with open(makefile_name, mode="w", encoding="utf-8") as mfile:
             mfile.write("# Makefile generated by ")
-            if PY3:
-                mfile.write(str(self.args))
-            else:
-                mfile.write(str(self.args).decode("unicode_escape"))
+            mfile.write(str(self.args))
             mfile.write("\n")
             for rule in self.rules:
                 rule.write(mfile)
