@@ -1,6 +1,3 @@
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import unittest
 import os
 import shutil
@@ -21,33 +18,34 @@ class TestLibrary(unittest.TestCase):
 
         # Mimic the build.sh and create the library in a 'mylib' subdirectory
         # Copy the sample source files into the test build location
-        mylibdir = os.path.join(self._tmpdir,'mylib')
-        shutil.copytree( os.path.join(uth.samplesdir(), 'library/mylib')
-                       , mylibdir)
+        mylibdir = os.path.join(self._tmpdir, "mylib")
+        shutil.copytree(os.path.join(uth.samplesdir(), "library/mylib"), mylibdir)
 
         # Build the library
         temp_config_name = uth.create_temp_config(self._tmpdir)
-        uth.create_temp_ct_conf(self._tmpdir,defaultvariant=temp_config_name[:-5])
-        argv = [ '--exemarkers=main'
-               , '--testmarkers=unittest.hpp'
-               , '--config='+temp_config_name
-               , '--CTCACHE=None'
-               , '--static'
-               , os.path.join(self._tmpdir,'mylib/get_numbers.cpp')
-               ]
+        uth.create_temp_ct_conf(self._tmpdir, defaultvariant=temp_config_name[:-5])
+        argv = [
+            "--exemarkers=main",
+            "--testmarkers=unittest.hpp",
+            "--config=" + temp_config_name,
+            "--CTCACHE=None",
+            "--static",
+            os.path.join(self._tmpdir, "mylib/get_numbers.cpp"),
+        ]
         os.chdir(mylibdir)
         uth.reset()
         ct.cake.main(argv)
 
         # Copy the main that will link to the library into the test build location
-        relativepaths = ['library/main.cpp']
-        realpaths = [os.path.join(uth.samplesdir(), filename)
-                     for filename in relativepaths]
+        relativepaths = ["library/main.cpp"]
+        realpaths = [
+            os.path.join(uth.samplesdir(), filename) for filename in relativepaths
+        ]
         for ff in realpaths:
             shutil.copy2(ff, self._tmpdir)
 
         # Build the exe, linking agains the library
-        argv = ['--config='+temp_config_name,'--CTCACHE=None'] + realpaths
+        argv = ["--config=" + temp_config_name, "--CTCACHE=None"] + realpaths
         os.chdir(self._tmpdir)
         uth.reset()
         ct.cake.main(argv)
@@ -60,17 +58,18 @@ class TestLibrary(unittest.TestCase):
                     actual_exes.add(ff)
 
         expected_exes = {
-            os.path.splitext(
-                os.path.split(filename)[1])[0] for filename in relativepaths}
+            os.path.splitext(os.path.split(filename)[1])[0]
+            for filename in relativepaths
+        }
         self.assertSetEqual(expected_exes, actual_exes)
 
         # Cleanup
         os.chdir(origdir)
         shutil.rmtree(self._tmpdir, ignore_errors=True)
-    
+
     def tearDown(self):
         uth.reset()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
